pub enum AlterTypeAddValuePosition {
Before(Ident),
After(Ident),
}Expand description
Variants
Before(Ident)
Place the new value before the given neighbor value.
After(Ident)
Place the new value after the given neighbor value.