pub enum ArrayElemTypeDef {
None,
AngleBracket(Box<DataType>),
SquareBracket(Box<DataType>, Option<u64>),
Parenthesis(Box<DataType>),
}Expand description
Represents the data type of the elements in an array (if any) as well as the syntax used to declare the array.
For example: Bigquery/Hive use ARRAY<INT> whereas snowflake uses ARRAY.
Variants
None
Use ARRAY style without an explicit element type.
AngleBracket(Box<DataType>)
Angle-bracket style, e.g. ARRAY<INT>.
SquareBracket(Box<DataType>, Option<u64>)
Square-bracket style, e.g. INT[] or INT[2].
Parenthesis(Box<DataType>)
Parenthesis style, e.g. Array(Int64).