GeneratedAs

Enum GeneratedAs 

pub enum GeneratedAs {
    Always,
    ByDefault,
    ExpStored,
}
GeneratedAss are modifiers that follow a column option in a generated. ‘ExpStored’ is used for a column generated from an expression and stored.

Variants



Always

GENERATED ALWAYS



ByDefault

GENERATED BY DEFAULT



ExpStored

Expression-based generated column that is stored (used internally for expression-stored columns)