pub enum MatchRecognizeSymbol {
Named(Ident),
Start,
End,
}Expand description
A symbol in a MATCH_RECOGNIZE pattern.
Variants
Named(Ident)
A named symbol, e.g. S1.
Start
A virtual symbol representing the start of the of partition (^).
End
A virtual symbol representing the end of the partition ($).