NormalizationForm

Enum NormalizationForm 

pub enum NormalizationForm {
    NFC,
    NFD,
    NFKC,
    NFKD,
}
The Unicode Standard defines four normalization forms, which are intended to eliminate certain distinctions between visually or functionally identical characters.

See Unicode Normalization Forms for details.

Variants



NFC

Canonical Decomposition, followed by Canonical Composition.



NFD

Canonical Decomposition.



NFKC

Compatibility Decomposition, followed by Canonical Composition.



NFKD

Compatibility Decomposition.