pub enum Subscript {
Index {
index: Expr,
},
Slice {
lower_bound: Option<Expr>,
upper_bound: Option<Expr>,
stride: Option<Expr>,
},
}Expand description
The contents inside the [ and ] in a subscript expression.
Variants
Index
Accesses the element of the array at the given index.
Slice
Accesses a slice of an array on PostgreSQL, e.g.
=> select (array[1,2,3,4,5,6])[2:5];
-----------
{2,3,4,5}The lower and/or upper bound can be omitted to slice from the start or end of the array respectively.
See https://www.postgresql.org/docs/current/arrays.html#ARRAYS-ACCESSING.
Also supports an optional “stride” as the last element (this is not supported by postgres), e.g.
=> select (array[1,2,3,4,5,6])[1:6:2];
-----------
{1,3,5}Trait Implementations
Sourceimpl Ord for Subscript
impl Ord for Subscript
Sourceimpl PartialOrd for Subscript
impl PartialOrd for Subscript
Sourceimpl VisitMut for Subscript
impl VisitMut for Subscript
Sourcefn visit<V: VisitorMut>(&mut self, visitor: &mut V) -> ControlFlow<V::Break>
fn visit<V: VisitorMut>(&mut self, visitor: &mut V) -> ControlFlow<V::Break>
Mutably visit this node with the provided
VisitorMut. Read moreimpl Eq for Subscript
impl StructuralPartialEq for Subscript