pub enum TriggerObject {
Row,
Statement,
}Expand description
This specifies whether the trigger function should be fired once for every row affected by the trigger event, or just once per SQL statement.
Variants
Row
The trigger fires once for each row affected by the triggering event
Statement
The trigger fires once for the triggering SQL statement