pub struct CreateIndex {Show 13 fields
pub name: Option<ObjectName>,
pub table_name: ObjectName,
pub using: Option<IndexType>,
pub columns: Vec<IndexColumn>,
pub unique: bool,
pub concurrently: bool,
pub if_not_exists: bool,
pub include: Vec<Ident>,
pub nulls_distinct: Option<bool>,
pub with: Vec<Expr>,
pub predicate: Option<Expr>,
pub index_options: Vec<IndexOption>,
pub alter_options: Vec<AlterTableOperation>,
}Expand description
CREATE INDEX statement.
Fields
name: Option<ObjectName>index name
table_name: ObjectNametable name
using: Option<IndexType>Index type used in the statement. Can also be found inside CreateIndex::index_options
depending on the position of the option within the statement.
columns: Vec<IndexColumn>columns included in the index
unique: boolwhether the index is unique
concurrently: boolwhether the index is created concurrently
if_not_exists: boolIF NOT EXISTS clause
include: Vec<Ident>INCLUDE clause: https://www.postgresql.org/docs/current/sql-createindex.html
nulls_distinct: Option<bool>NULLS DISTINCT / NOT DISTINCT clause: https://www.postgresql.org/docs/current/sql-createindex.html
with: Vec<Expr>predicate: Option<Expr>index_options: Vec<IndexOption>Index options: https://www.postgresql.org/docs/current/sql-createindex.html
alter_options: Vec<AlterTableOperation>MySQL allows a subset of options normally used for ALTER TABLE:
ALGORITHMLOCK