pub struct Function {
pub name: ObjectName,
pub uses_odbc_syntax: bool,
pub parameters: FunctionArguments,
pub args: FunctionArguments,
pub filter: Option<Box<Expr>>,
pub null_treatment: Option<NullTreatment>,
pub over: Option<WindowType>,
pub within_group: Vec<OrderByExpr>,
}Expand description
A function call
Fields
name: ObjectNameThe function name (may be qualified).
uses_odbc_syntax: boolparameters: FunctionArgumentsThe parameters to the function, including any options specified within the delimiting parentheses.
Example:
HISTOGRAM(0.5, 0.6)(x, y)args: FunctionArgumentsThe arguments to the function, including any options specified within the delimiting parentheses.
filter: Option<Box<Expr>>e.g. x > 5 in COUNT(x) FILTER (WHERE x > 5)
null_treatment: Option<NullTreatment>Indicates how NULLs should be handled in the calculation.
Example:
FIRST_VALUE( <expr> ) [ { IGNORE | RESPECT } NULLS ] OVER ...over: Option<WindowType>The OVER clause, indicating a window function call.
within_group: Vec<OrderByExpr>A clause used with certain aggregate functions to control the ordering within grouped sets before the function is applied.
Syntax:
<aggregate_function>(expression) WITHIN GROUP (ORDER BY key [ASC | DESC], ...)Trait Implementations
Sourceimpl Ord for Function
impl Ord for Function
Sourceimpl PartialOrd for Function
impl PartialOrd for Function
Sourceimpl VisitMut for Function
impl VisitMut for Function
Sourcefn visit<V: VisitorMut>(&mut self, visitor: &mut V) -> ControlFlow<V::Break>
fn visit<V: VisitorMut>(&mut self, visitor: &mut V) -> ControlFlow<V::Break>
Mutably visit this node with the provided
VisitorMut. Read moreimpl Eq for Function
impl StructuralPartialEq for Function