pub struct ObjectNamePartFunction {
pub name: Ident,
pub args: Vec<FunctionArg>,
}Expand description
An object name part that consists of a function that dynamically constructs identifiers.
Fields
name: IdentThe function name that produces the object name part.
args: Vec<FunctionArg>Function arguments used to compute the identifier.