pub struct OptimizerHint {
pub text: String,
pub style: OptimizerHintStyle,
}Expand description
Query optimizer hints are optionally supported comments after the
SELECT, INSERT, UPDATE, REPLACE, MERGE, and DELETE keywords in
the corresponding statements.
Fields
text: Stringthe raw test of the optimizer hint without its markers
style: OptimizerHintStylethe style of the comment which text was extracted from,
e.g. /*+...*/ or --+...
Not all dialects support all styles, though.