pub struct TriggerReferencing {
pub refer_type: TriggerReferencingType,
pub is_as: bool,
pub transition_relation_name: ObjectName,
}Expand description
This keyword immediately precedes the declaration of one or two relation names that provide access to the transition relations of the triggering statement
Fields
refer_type: TriggerReferencingTypeThe referencing type (OLD TABLE or NEW TABLE).
is_as: boolTrue if the AS keyword is present in the referencing clause.
transition_relation_name: ObjectNameThe transition relation name provided by the referencing clause.