pub struct VacuumStatement {
pub full: bool,
pub sort_only: bool,
pub delete_only: bool,
pub reindex: bool,
pub recluster: bool,
pub table_name: Option<ObjectName>,
pub threshold: Option<Value>,
pub boost: bool,
}Expand description
Re-sorts rows and reclaims space in either a specified table or all tables in the current database
‘’’sql VACUUM [ FULL | SORT ONLY | DELETE ONLY | REINDEX | RECLUSTER ] [ [ table_name ] [ TO threshold PERCENT ] [ BOOST ] ] ‘’’ Redshift
Fields
full: boolWhether FULL was specified.
sort_only: boolWhether SORT ONLY was specified.
delete_only: boolWhether DELETE ONLY was specified.
reindex: boolWhether REINDEX was specified.
recluster: boolWhether RECLUSTER was specified.
table_name: Option<ObjectName>Optional table to run VACUUM on.
threshold: Option<Value>Optional threshold value (percent) for TO threshold PERCENT.
boost: boolWhether BOOST was specified.