pub enum CreateViewSecurity {
Definer,
Invoker,
}Expand description
MySQL CREATE VIEW security parameter: [SQL SECURITY { DEFINER | INVOKER }]
MySQL CREATE VIEW SQL SECURITY options.
Variants
Definer
The view runs with the privileges of the definer.
Invoker
The view runs with the privileges of the invoker.