pub fn escape_quoted_string(string: &str, quote: char) -> EscapeQuotedString<'_>
Return a helper which formats string for inclusion inside a quoted literal that uses quote as the delimiter.
string
quote