pub struct ColumnPolicyProperty {
pub with: bool,
pub policy_name: ObjectName,
pub using_columns: Option<Vec<Ident>>,
}Expand description
Properties describing a column policy (masking or projection).
Fields
with: boolThis flag indicates that the column policy option is declared using the WITH prefix.
Example
WITH PROJECTION POLICY sample_policypolicy_name: ObjectNameThe name of the policy to apply to the column.
using_columns: Option<Vec<Ident>>Optional list of column identifiers referenced by the policy.